@@ -2,6 +2,11 @@ import json
 import base64
 import requests
 import threading
+from hashlib import sha1
+import names
+import random
+import hmac
+import platform,socket,re,uuid 
 import secmail
 from bs4 import BeautifulSoup
 from uuid import UUID
@@ -261,7 +266,7 @@ class Client(Callbacks, SocketHandler):
             "timestamp": int(timestamp() * 1000)
         })
 
-        response = requests.post(f"{self.api}/g/s/auth/login", headers=self.parse_headers(data=data), data=data, proxies=self.proxies, verify=self.certificatePath)
+        response = requests.post(f"{self.api}/g/s/auth/login", headers=self.parse_headers(data=data,deviceId=self.devicee()), data=data, proxies=self.proxies, verify=self.certificatePath)
         #print(self.parse_headers(data=data))
         self.run_socket()
         if response.status_code != 200: return exceptions.CheckException(json.loads(response.text))
@@ -2072,8 +2077,10 @@ class Client(Callbacks, SocketHandler):
         else: return json.loads(response.text)["supportedLanguages"]
 
     def devicee(self):
-        dev=requests.get("https://devgen17.herokuapp.com/dev")
-        return dev.json()["dev"]
+        hw=(names.get_full_name()+str(random.randint(0,10000000))+platform.version()+platform.machine()+names.get_first_name()+socket.gethostbyname(socket.gethostname())+':'.join(re.findall('..', '%012x' % uuid.getnode()))+platform.processor())
+        identifier=sha1(hw.encode('utf-8')).digest()
+        mac = hmac.new(bytes.fromhex('76b4a156aaccade137b8b1e77b435a81971fbd3e'), b"\x32" + identifier, sha1)
+        return (f"32{identifier.hex()}{mac.hexdigest()}").upper()
 
     def claim_new_user_coupon(self):
         """
